==> core-1.63.0-sources.jar: software/amazon/awscdk/core/CfnCodeDeployBlueGreenHookProps.java <==
package software.amazon.awscdk.core;

/**
 * Construction properties of {@link CfnCodeDeployBlueGreenHook}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.11.0 (build 1e9b8e1)", date = "2020-09-13T06:02:40.339Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.CfnCodeDeployBlueGreenHookProps")
@software.amazon.jsii.Jsii.Proxy(CfnCodeDeployBlueGreenHookProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeDeployBlueGreenHookProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Properties of the Amazon ECS applications being deployed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> getApplications();

    /**
     * The IAM Role for CloudFormation to use to perform blue-green deployments.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getServiceRole();

    /**
     * Additional options for the blue/green deployment.
     * <p>
     * Default: - no additional options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions getAdditionalOptions() {
        return null;
    }

    /**
     * Use lifecycle event hooks to specify a Lambda function that CodeDeploy can call to validate a deployment.
     * <p>
     * You can use the same function or a different one for deployment lifecycle events.
     * Following completion of the validation tests,
     * the Lambda {&#64;link CfnCodeDeployBlueGreenLifecycleEventHooks.afterAllowTraffic}
     * function calls back CodeDeploy and delivers a result of 'Succeeded' or 'Failed'.
     * <p>
     * Default: - no lifecycle event hooks
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks getLifecycleEventHooks() {
        return null;
    }

    /**
     * Traffic routing configuration settings.
     * <p>
     * Default: - time-based canary traffic shifting, with a 15% step percentage and a five minute bake time
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnTrafficRoutingConfig getTrafficRoutingConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeDeployBlueGreenHookProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeDeployBlueGreenHookProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeDeployBlueGreenHookProps> {
        private java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications;
        private java.lang.String serviceRole;
        private software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions;
        private software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks;
        private software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig;

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getApplications}
         * @param applications Properties of the Amazon ECS applications being deployed. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applications(java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications) {
            this.applications = applications;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getServiceRole}
         * @param serviceRole The IAM Role for CloudFormation to use to perform blue-green deployments. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serviceRole(java.lang.String serviceRole) {
            this.serviceRole = serviceRole;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getAdditionalOptions}
         * @param additionalOptions Additional options for the blue/green deployment.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder additionalOptions(software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions) {
            this.additionalOptions = additionalOptions;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getLifecycleEventHooks}
         * @param lifecycleEventHooks Use lifecycle event hooks to specify a Lambda function that CodeDeploy can call to validate a deployment.
         *                            You can use the same function or a different one for deployment lifecycle events.
         *                            Following completion of the validation tests,
         *                            the Lambda {&#64;link CfnCodeDeployBlueGreenLifecycleEventHooks.afterAllowTraffic}
         *                            function calls back CodeDeploy and delivers a result of 'Succeeded' or 'Failed'.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lifecycleEventHooks(software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks) {
            this.lifecycleEventHooks = lifecycleEventHooks;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getTrafficRoutingConfig}
         * @param trafficRoutingConfig Traffic routing configuration settings.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficRoutingConfig(software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig) {
            this.trafficRoutingConfig = trafficRoutingConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeDeployBlueGreenHookProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeDeployBlueGreenHookProps build() {
            return new Jsii$Proxy(applications, serviceRole, additionalOptions, lifecycleEventHooks, trafficRoutingConfig);
        }
    }

    /**
     * An implementation for {@link CfnCodeDeployBlueGreenHookProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeDeployBlueGreenHookProps {
        private final java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications;
        private final java.lang.String serviceRole;
        private final software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions;
        private final software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks;
        private final software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applications = this.jsiiGet("applications", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication.class)));
            this.serviceRole = this.jsiiGet("serviceRole", java.lang.String.class);
            this.additionalOptions = this.jsiiGet("additionalOptions", software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions.class);
            this.lifecycleEventHooks = this.jsiiGet("lifecycleEventHooks", software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks.class);
            this.trafficRoutingConfig = this.jsiiGet("trafficRoutingConfig", software.amazon.awscdk.core.CfnTrafficRoutingConfig.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications, final java.lang.String serviceRole, final software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions, final software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks, final software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applications = java.util.Objects.requireNonNull(applications, "applications is required");
            this.serviceRole = java.util.Objects.requireNonNull(serviceRole, "serviceRole is required");
            this.additionalOptions = additionalOptions;
            this.lifecycleEventHooks = lifecycleEventHooks;
            this.trafficRoutingConfig = trafficRoutingConfig;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> getApplications() {
            return this.applications;
        }

        @Override
        public java.lang.String getServiceRole() {
            return this.serviceRole;
        }

        @Override
        public software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions getAdditionalOptions() {
            return this.additionalOptions;
        }

        @Override
        public software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks getLifecycleEventHooks() {
            return this.lifecycleEventHooks;
        }

        @Override
        public software.amazon.awscdk.core.CfnTrafficRoutingConfig getTrafficRoutingConfig() {
            return this.trafficRoutingConfig;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("applications", om.valueToTree(this.getApplications()));
            data.set("serviceRole", om.valueToTree(this.getServiceRole()));
            if (this.getAdditionalOptions() != null) {
                data.set("additionalOptions", om.valueToTree(this.getAdditionalOptions()));
            }
            if (this.getLifecycleEventHooks() != null) {
                data.set("lifecycleEventHooks", om.valueToTree(this.getLifecycleEventHooks()));
            }
            if (this.getTrafficRoutingConfig() != null) {
                data.set("trafficRoutingConfig", om.valueToTree(this.getTrafficRoutingConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.CfnCodeDeployBlueGreenHookProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeDeployBlueGreenHookProps.Jsii$Proxy that = (CfnCodeDeployBlueGreenHookProps.Jsii$Proxy) o;

            if (!applications.equals(that.applications)) return false;
            if (!serviceRole.equals(that.serviceRole)) return false;
            if (this.additionalOptions != null ? !this.additionalOptions.equals(that.additionalOptions) : that.additionalOptions != null) return false;
            if (this.lifecycleEventHooks != null ? !this.lifecycleEventHooks.equals(that.lifecycleEventHooks) : that.lifecycleEventHooks != null) return false;
            return this.trafficRoutingConfig != null ? this.trafficRoutingConfig.equals(that.trafficRoutingConfig) : that.trafficRoutingConfig == null;
        }

        @Override
        public int hashCode() {
            int result = this.applications.hashCode();
            result = 31 * result + (this.serviceRole.hashCode());
            result = 31 * result + (this.additionalOptions != null ? this.additionalOptions.hashCode() : 0);
            result = 31 * result + (this.lifecycleEventHooks != null ? this.lifecycleEventHooks.hashCode() : 0);
            result = 31 * result + (this.trafficRoutingConfig != null ? this.trafficRoutingConfig.hashCode() : 0);
            return result;
        }
    }
}

==> core-1.64.0-sources.jar: software/amazon/awscdk/core/CfnCodeDeployBlueGreenHookProps.java <==
package software.amazon.awscdk.core;

/**
 * Construction properties of {@link CfnCodeDeployBlueGreenHook}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.12.0 (build 5ddc9f2)", date = "2020-09-22T23:51:18.616Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.CfnCodeDeployBlueGreenHookProps")
@software.amazon.jsii.Jsii.Proxy(CfnCodeDeployBlueGreenHookProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeDeployBlueGreenHookProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Properties of the Amazon ECS applications being deployed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> getApplications();

    /**
     * The IAM Role for CloudFormation to use to perform blue-green deployments.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getServiceRole();

    /**
     * Additional options for the blue/green deployment.
     * <p>
     * Default: - no additional options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions getAdditionalOptions() {
        return null;
    }

    /**
     * Use lifecycle event hooks to specify a Lambda function that CodeDeploy can call to validate a deployment.
     * <p>
     * You can use the same function or a different one for deployment lifecycle events.
     * Following completion of the validation tests,
     * the Lambda {&#64;link CfnCodeDeployBlueGreenLifecycleEventHooks.afterAllowTraffic}
     * function calls back CodeDeploy and delivers a result of 'Succeeded' or 'Failed'.
     * <p>
     * Default: - no lifecycle event hooks
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks getLifecycleEventHooks() {
        return null;
    }

    /**
     * Traffic routing configuration settings.
     * <p>
     * Default: - time-based canary traffic shifting, with a 15% step percentage and a five minute bake time
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.CfnTrafficRoutingConfig getTrafficRoutingConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeDeployBlueGreenHookProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeDeployBlueGreenHookProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeDeployBlueGreenHookProps> {
        private java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications;
        private java.lang.String serviceRole;
        private software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions;
        private software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks;
        private software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig;

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getApplications}
         * @param applications Properties of the Amazon ECS applications being deployed. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder applications(java.util.List<? extends software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications) {
            this.applications = (java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication>)applications;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getServiceRole}
         * @param serviceRole The IAM Role for CloudFormation to use to perform blue-green deployments. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serviceRole(java.lang.String serviceRole) {
            this.serviceRole = serviceRole;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getAdditionalOptions}
         * @param additionalOptions Additional options for the blue/green deployment.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder additionalOptions(software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions) {
            this.additionalOptions = additionalOptions;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getLifecycleEventHooks}
         * @param lifecycleEventHooks Use lifecycle event hooks to specify a Lambda function that CodeDeploy can call to validate a deployment.
         *                            You can use the same function or a different one for deployment lifecycle events.
         *                            Following completion of the validation tests,
         *                            the Lambda {&#64;link CfnCodeDeployBlueGreenLifecycleEventHooks.afterAllowTraffic}
         *                            function calls back CodeDeploy and delivers a result of 'Succeeded' or 'Failed'.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lifecycleEventHooks(software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks) {
            this.lifecycleEventHooks = lifecycleEventHooks;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenHookProps#getTrafficRoutingConfig}
         * @param trafficRoutingConfig Traffic routing configuration settings.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficRoutingConfig(software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig) {
            this.trafficRoutingConfig = trafficRoutingConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeDeployBlueGreenHookProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeDeployBlueGreenHookProps build() {
            return new Jsii$Proxy(applications, serviceRole, additionalOptions, lifecycleEventHooks, trafficRoutingConfig);
        }
    }

    /**
     * An implementation for {@link CfnCodeDeployBlueGreenHookProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeDeployBlueGreenHookProps {
        private final java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications;
        private final java.lang.String serviceRole;
        private final software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions;
        private final software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks;
        private final software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applications = this.jsiiGet("applications", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication.class)));
            this.serviceRole = this.jsiiGet("serviceRole", java.lang.String.class);
            this.additionalOptions = this.jsiiGet("additionalOptions", software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions.class);
            this.lifecycleEventHooks = this.jsiiGet("lifecycleEventHooks", software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks.class);
            this.trafficRoutingConfig = this.jsiiGet("trafficRoutingConfig", software.amazon.awscdk.core.CfnTrafficRoutingConfig.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        private Jsii$Proxy(final java.util.List<? extends software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> applications, final java.lang.String serviceRole, final software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions additionalOptions, final software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks lifecycleEventHooks, final software.amazon.awscdk.core.CfnTrafficRoutingConfig trafficRoutingConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applications = (java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication>)java.util.Objects.requireNonNull(applications, "applications is required");
            this.serviceRole = java.util.Objects.requireNonNull(serviceRole, "serviceRole is required");
            this.additionalOptions = additionalOptions;
            this.lifecycleEventHooks = lifecycleEventHooks;
            this.trafficRoutingConfig = trafficRoutingConfig;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnCodeDeployBlueGreenApplication> getApplications() {
            return this.applications;
        }

        @Override
        public java.lang.String getServiceRole() {
            return this.serviceRole;
        }

        @Override
        public software.amazon.awscdk.core.CfnCodeDeployBlueGreenAdditionalOptions getAdditionalOptions() {
            return this.additionalOptions;
        }

        @Override
        public software.amazon.awscdk.core.CfnCodeDeployBlueGreenLifecycleEventHooks getLifecycleEventHooks() {
            return this.lifecycleEventHooks;
        }

        @Override
        public software.amazon.awscdk.core.CfnTrafficRoutingConfig getTrafficRoutingConfig() {
            return this.trafficRoutingConfig;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("applications", om.valueToTree(this.getApplications()));
            data.set("serviceRole", om.valueToTree(this.getServiceRole()));
            if (this.getAdditionalOptions() != null) {
                data.set("additionalOptions", om.valueToTree(this.getAdditionalOptions()));
            }
            if (this.getLifecycleEventHooks() != null) {
                data.set("lifecycleEventHooks", om.valueToTree(this.getLifecycleEventHooks()));
            }
            if (this.getTrafficRoutingConfig() != null) {
                data.set("trafficRoutingConfig", om.valueToTree(this.getTrafficRoutingConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.CfnCodeDeployBlueGreenHookProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeDeployBlueGreenHookProps.Jsii$Proxy that = (CfnCodeDeployBlueGreenHookProps.Jsii$Proxy) o;

            if (!applications.equals(that.applications)) return false;
            if (!serviceRole.equals(that.serviceRole)) return false;
            if (this.additionalOptions != null ? !this.additionalOptions.equals(that.additionalOptions) : that.additionalOptions != null) return false;
            if (this.lifecycleEventHooks != null ? !this.lifecycleEventHooks.equals(that.lifecycleEventHooks) : that.lifecycleEventHooks != null) return false;
            return this.trafficRoutingConfig != null ? this.trafficRoutingConfig.equals(that.trafficRoutingConfig) : that.trafficRoutingConfig == null;
        }

        @Override
        public int hashCode() {
            int result = this.applications.hashCode();
            result = 31 * result + (this.serviceRole.hashCode());
            result = 31 * result + (this.additionalOptions != null ? this.additionalOptions.hashCode() : 0);
            result = 31 * result + (this.lifecycleEventHooks != null ? this.lifecycleEventHooks.hashCode() : 0);
            result = 31 * result + (this.trafficRoutingConfig != null ? this.trafficRoutingConfig.hashCode() : 0);
            return result;
        }
    }
}
